@@ -31,6 +31,7 @@ ARTEFACTS = [
     "mcp_romfw.bin",
     "android-nano.img.xz",
     "busybox.img.xz",
+    "debian.img.xz",
     "core-image-minimal-morello-fvp.wic",
     "scp_fw.bin",
     "scp_romfw.bin",
@@ -88,6 +89,15 @@ def artefacts(tmp_path):
             ["--device", "qemu-arm64", "--tests", "ltp-fcntl-locktests"],
             "qemu-arm64-ltp-fcntl-locktests.yaml",
         ),
+        (
+            [
+                "--device",
+                "qemu-arm64",
+                "--tests",
+                "kselftest-arm64",
+            ],
+            "qemu-arm64-kselftest-arm64.yaml",
+        ),
         (
             ["--device", "qemu-arm64be"],
             "qemu-arm64be.yaml",
@@ -182,6 +192,10 @@ def artefacts(tmp_path):
             ["--device", "qemu-armv7be"],
             "qemu-armv7be.yaml",
         ),
+        (
+            ["--device", "qemu-armv7be", "--prompt", "root@tuxrun"],
+            "qemu-armv7be-prompt.yaml",
+        ),
         (
             ["--device", "qemu-i386"],
             "qemu-i386.yaml",
@@ -408,6 +422,15 @@ def artefacts(tmp_path):
             ],
             "fvp-aemva.yaml",
         ),
+        (
+            [
+                "--device",
+                "fvp-aemva",
+                "--prompt",
+                "root@tuxrun",
+            ],
+            "fvp-aemva-prompt.yaml",
+        ),
         (
             [
                 "--device",
@@ -686,6 +709,29 @@ def artefacts(tmp_path):
             ],
             "fvp-morello-busybox-purecap.yaml",
         ),
+        (
+            [
+                "--device",
+                "fvp-morello-debian",
+                "--ap-romfw",
+                "tf-bl1.bin",
+                "--mcp-fw",
+                "mcp_fw.bin",
+                "--mcp-romfw",
+                "mcp_romfw.bin",
+                "--rootfs",
+                "debian.img.xz",
+                "--scp-fw",
+                "scp_fw.bin",
+                "--scp-romfw",
+                "scp_romfw.bin",
+                "--fip",
+                "fip.bin",
+                "--tests",
+                "debian-purecap",
+            ],
+            "fvp-morello-debian-purecap.yaml",
+        ),
         (
             [
                 "--device",
@@ -787,11 +833,7 @@ def test_fvm_aemva_extra_assets(tmpdir):
     device = Device.select("fvp-aemva")()
 
     # 1/ default case
-    asset = device.extra_assets(
-        dtb=None,
-        kernel=None,
-        tmpdir=tmpdir,
-    )
+    asset = device.extra_assets(dtb=None, kernel=None, tmpdir=tmpdir, tux_boot_args="")
     assert len(asset) == 1
     assert asset[0] == f"file://{tmpdir / 'startup.nsh'}"
     assert (tmpdir / "startup.nsh").read_text(
@@ -803,6 +845,7 @@ def test_fvm_aemva_extra_assets(tmpdir):
         dtb="file://hello/world/fdt.dtb",
         kernel="http://example.com/kernel",
         tmpdir=tmpdir,
+        tux_boot_args="",
     )
     assert len(asset) == 1
     assert asset[0] == f"file://{tmpdir / 'startup.nsh'}"
@@ -812,12 +855,20 @@ def test_fvm_aemva_extra_assets(tmpdir):
 
     # 3/ compression
     asset = device.extra_assets(
-        dtb="file://tmp/my-dtb",
-        kernel="Image.gz",
-        tmpdir=tmpdir,
+        dtb="file://tmp/my-dtb", kernel="Image.gz", tmpdir=tmpdir, tux_boot_args=None
     )
     assert len(asset) == 1
     assert asset[0] == f"file://{tmpdir / 'startup.nsh'}"
     assert (tmpdir / "startup.nsh").read_text(
         encoding="utf-8"
     ) == "Image dtb=my-dtb console=ttyAMA0 earlycon=pl011,0x1c090000 root=/dev/vda ip=dhcp"
+
+    # 4/ custom boot-args
+    asset = device.extra_assets(
+        dtb=None, kernel=None, tmpdir=tmpdir, tux_boot_args="debug"
+    )
+    assert len(asset) == 1
+    assert asset[0] == f"file://{tmpdir / 'startup.nsh'}"
+    assert (tmpdir / "startup.nsh").read_text(
+        encoding="utf-8"
+    ) == "Image dtb=fvp-base-revc.dtb debug console=ttyAMA0 earlycon=pl011,0x1c090000 root=/dev/vda ip=dhcp"
